@@ -1,8 +1,6 @@
 /* fuse.c: The Free Unix Spectrum Emulator
    Copyright (c) 1999-2016 Philip Kendall and others
 
-   $Id: fuse.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -302,7 +300,9 @@ run_startup_manager( int *argc, char ***argv )
   fuller_register_startup();
   if1_register_startup();
   if2_register_startup();
+  joystick_register_startup();
   kempmouse_register_startup();
+  keyboard_register_startup();
   libspectrum_register_startup();
   libxml2_register_startup();
   machine_register_startup();
@@ -373,14 +373,7 @@ static int fuse_init(int argc, char **argv)
 
   start_scaler = utils_safe_strdup( settings_current.start_scaler_mode );
 
-  /* Windows will create a console for our output if there isn't one already,
-   * so we don't display the copyright message on Win32. */
-#ifndef WIN32
   fuse_show_copyright();
-#endif
-
-  fuse_joystick_init();
-  fuse_keyboard_init();
 
   if( run_startup_manager( &argc, &argv ) ) return 1;
 
@@ -930,8 +923,6 @@ static int fuse_end(void)
   startup_manager_run_end();
 
   periph_end();
-  fuse_keyboard_end();
-  fuse_joystick_end();
   ui_end();
   ui_media_drive_end();
   module_end();
