@@ -1,7 +1,5 @@
 /* keyboard.c: Routines for dealing with the Spectrum's keyboard
-   Copyright (c) 1999-2013 Philip Kendall
-
-   $Id: keyboard.c 5434 2016-05-01 04:22:45Z fredm $
+   Copyright (c) 1999-2016 Philip Kendall
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,8 +29,9 @@
 
 #include <libspectrum.h>
 
-#include "ui/ui.h"
+#include "infrastructure/startup_manager.h"
 #include "keyboard.h"
+#include "ui/ui.h"
 
 /* Bit masks for each of the eight keyboard half-rows; `AND' the selected
    ones of these to get the value to return
@@ -106,6 +105,14 @@ static struct spectrum_keys_wrapper spectrum_keys_table[] = {
   { INPUT_KEY_slash,       { KEYBOARD_v,     KEYBOARD_Symbol } },
   { INPUT_KEY_Shift_R,     { KEYBOARD_NONE,  KEYBOARD_Caps   } },
 
+  { INPUT_KEY_asterisk,    { KEYBOARD_b,     KEYBOARD_Symbol } },
+  { INPUT_KEY_dollar,      { KEYBOARD_4,     KEYBOARD_Symbol } },
+  { INPUT_KEY_exclam,      { KEYBOARD_1,     KEYBOARD_Symbol } },
+  { INPUT_KEY_less,        { KEYBOARD_r,     KEYBOARD_Symbol } },
+  { INPUT_KEY_parenright,  { KEYBOARD_9,     KEYBOARD_Symbol } },
+  { INPUT_KEY_colon,       { KEYBOARD_z,     KEYBOARD_Symbol } },
+  { INPUT_KEY_plus,        { KEYBOARD_k,     KEYBOARD_Symbol } },
+
   { INPUT_KEY_Control_L,   { KEYBOARD_NONE,  KEYBOARD_Symbol } },
   { INPUT_KEY_Alt_L,       { KEYBOARD_NONE,  KEYBOARD_Symbol } },
   { INPUT_KEY_Meta_L,      { KEYBOARD_NONE,  KEYBOARD_Symbol } },
@@ -119,10 +126,10 @@ static struct spectrum_keys_wrapper spectrum_keys_table[] = {
   { INPUT_KEY_Control_R,   { KEYBOARD_NONE,  KEYBOARD_Symbol } },
   { INPUT_KEY_Mode_switch, { KEYBOARD_NONE,  KEYBOARD_Symbol } },
 
-  { INPUT_KEY_Left,        { KEYBOARD_5,     KEYBOARD_Caps   } },
-  { INPUT_KEY_Down,        { KEYBOARD_6,     KEYBOARD_Caps   } },
-  { INPUT_KEY_Up,          { KEYBOARD_7,     KEYBOARD_Caps   } },
-  { INPUT_KEY_Right,       { KEYBOARD_8,     KEYBOARD_Caps   } },
+  { INPUT_KEY_Left,        { KEYBOARD_5,     KEYBOARD_NONE   } },
+  { INPUT_KEY_Down,        { KEYBOARD_6,     KEYBOARD_NONE   } },
+  { INPUT_KEY_Up,          { KEYBOARD_7,     KEYBOARD_NONE   } },
+  { INPUT_KEY_Right,       { KEYBOARD_8,     KEYBOARD_NONE   } },
 
   { INPUT_KEY_KP_Enter,    { KEYBOARD_Enter, KEYBOARD_NONE   } },
 
@@ -260,9 +267,8 @@ struct key_text_t key_text_table[] = {
 
 static GHashTable *key_text;
 
-/* Called `fuse_keyboard_init' as svgalib pollutes the global namespace
-   with keyboard_init... */
-void fuse_keyboard_init(void)
+static int
+keyboard_init( void *context )
 {
   struct key_info *ptr;
   struct spectrum_keys_wrapper *ptr2;
@@ -292,9 +298,11 @@ void fuse_keyboard_init(void)
   for( ptr4 = key_text_table; ptr4->text != NULL; ptr4++ )
     g_hash_table_insert( key_text, &( ptr4->key ), &( ptr4->text ) );
 
+  return 0;
 }
 
-void fuse_keyboard_end(void)
+static void
+keyboard_end( void )
 {
   g_hash_table_destroy( keyboard_data );
   g_hash_table_destroy( spectrum_keys );
@@ -302,6 +310,18 @@ void fuse_keyboard_end(void)
   g_hash_table_destroy( key_text );
 }
 
+void
+keyboard_register_startup( void )
+{
+  startup_manager_module dependencies[] = {
+    STARTUP_MANAGER_MODULE_LIBSPECTRUM,
+    STARTUP_MANAGER_MODULE_SETUID
+  };
+  startup_manager_register( STARTUP_MANAGER_MODULE_KEYBOARD, dependencies,
+                            ARRAY_SIZE( dependencies ), keyboard_init,
+                            keyboard_end, NULL );
+}
+
 libspectrum_byte
 keyboard_read( libspectrum_byte porth )
 {
