@@ -1,8 +1,6 @@
 /* machine.c: Routines for handling the various machine types
    Copyright (c) 1999-2015 Philip Kendall
 
-   $Id: machine.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -437,7 +435,10 @@ machine_end( void )
 void
 machine_register_startup( void )
 {
-  startup_manager_module dependencies[] = { STARTUP_MANAGER_MODULE_SETUID };
+  startup_manager_module dependencies[] = {
+    STARTUP_MANAGER_MODULE_MEMORY,
+    STARTUP_MANAGER_MODULE_SETUID
+  };
   startup_manager_register( STARTUP_MANAGER_MODULE_MACHINE, dependencies,
                             ARRAY_SIZE( dependencies ), machine_init_machines,
                             NULL, machine_end );
