@@ -2,8 +2,6 @@
    Copyright (c) 2000-2016 Russell Marks, Matan Ziv-Av, Philip Kendall,
                            Fredrick Meunier, Patrik Rak
 
-   $Id: sound.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -178,6 +176,23 @@ sound_ay_init( void )
   ay_change_count = 0;
 }
 
+#ifndef UI_WIN32
+#define MIN_SPEED_PERCENTAGE 2
+#define MAX_SPEED_PERCENTAGE 500
+#else                        /* #ifndef UI_WIN32 */
+/* We are limiting speed until bugs in the DirectSound driver are resolved, see
+   [bugs:#364] for more details */
+#define MIN_SPEED_PERCENTAGE 50
+#define MAX_SPEED_PERCENTAGE 300
+#endif                       /* #ifndef UI_WIN32 */
+
+static int
+is_in_sound_enabled_range( void )
+{
+  return settings_current.emulation_speed >= MIN_SPEED_PERCENTAGE &&
+    settings_current.emulation_speed <= MAX_SPEED_PERCENTAGE;
+}
+
 void
 sound_init( const char *device )
 {
@@ -193,7 +208,7 @@ sound_init( const char *device )
      than a seconds worth of sound which is bigger than the
      maximum Blip_Buffer of 1 second) */
   if( !( !sound_enabled && settings_current.sound &&
-         settings_current.emulation_speed > 1 ) )
+         is_in_sound_enabled_range() ) )
     return;
 
   /* only try for stereo if we need it */
