@@ -2,8 +2,6 @@
    Copyright (c) 2002-2015 Philip Kendall
    Copyright (c) 2016 Sergio Baldoví
 
-   $Id: ui.c 5434 2016-05-01 04:22:45Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -50,10 +48,8 @@ int ui_widget_level = -1;
 static char last_message[ MESSAGE_MAX_LENGTH ] = "";
 static size_t frames_since_last_message = 0;
 
-#ifndef UI_WIN32
 static int
 print_error_to_stderr( ui_error_level severity, const char *message );
-#endif			/* #ifndef UI_WIN32 */
 
 int
 ui_error( ui_error_level severity, const char *format, ... )
@@ -85,9 +81,7 @@ ui_verror( ui_error_level severity, const char *format, va_list ap )
   strncpy( last_message, message, MESSAGE_MAX_LENGTH );
   last_message[ MESSAGE_MAX_LENGTH - 1 ] = '\0';
 
-#ifndef UI_WIN32
   print_error_to_stderr( severity, message );
-#endif			/* #ifndef UI_WIN32 */
 
   /* Do any UI-specific bits as well */
   ui_error_specific( severity, message );
